
# Slot: increases mutation rate of


holds between a molecular entity and a genomic entity where the action or effect of the molecular entity increases the rate of mutation of the genomic entity within a system of interest

URI: [biolink:increases_mutation_rate_of](https://w3id.org/biolink/vocab/increases_mutation_rate_of)


## Domain and Range

[MolecularEntity](MolecularEntity.md) &#8594;  <sub>0..\*</sub> [GenomicEntity](GenomicEntity.md)

## Parents

 *  is_a: [affects mutation rate of](affects_mutation_rate_of.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | CTD:increases_mutation_rate_of |
| **Broad Mappings:** | | CTD:increases_mutagenesis |

